@@ -40,6 +40,7 @@ build_time_vars = {'ABIFLAGS': 'm',
                             '-Werror=implicit-function-declaration',
  'CONFIGURE_CPPFLAGS': '-D_FORTIFY_SOURCE=2',
  'CONFIGURE_LDFLAGS': '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now',
+ 'CONFIGURE_LDFLAGS_NODIST': '',
  'CONFIG_ARGS': "'--prefix=/usr' '--enable-shared' '--with-threads' "
                 "'--with-computed-gotos' '--without-lto' '--enable-ipv6' "
                 "'--with-system-expat' '--with-dbmliborder=gdbm:ndbm' "
@@ -52,8 +53,8 @@ build_time_vars = {'ABIFLAGS': 'm',
  'CONFINCLUDEDIR': '/usr/include',
  'CONFINCLUDEPY': '/usr/include/python3.7m',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/build/python/src/Python-3.7.1/coverage.info',
- 'COVERAGE_REPORT': '/build/python/src/Python-3.7.1/lcov-report',
+ 'COVERAGE_INFO': '/build/python/src/Python-3.7.2/coverage.info',
+ 'COVERAGE_REPORT': '/build/python/src/Python-3.7.2/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
  'CPPFLAGS': '-I. -I./Include -D_FORTIFY_SOURCE=2 -D_FORTIFY_SOURCE=2',
@@ -509,6 +510,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'LDCXXSHARED': 'g++ -pthread -shared',
  'LDFLAGS': '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now '
             '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now',
+ 'LDFLAGS_NODIST': '',
  'LDLAST': '',
  'LDLIBRARY': 'libpython3.7m.so',
  'LDLIBRARYDIR': '',
@@ -610,6 +612,20 @@ build_time_vars = {'ABIFLAGS': 'm',
  'PYTHON_FOR_REGEN': 'python3.7',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
+ 'PY_BUILTIN_MODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g '
+                             '-fwrapv -O3 -Wall -march=armv6 -mfloat-abi=hard '
+                             '-mfpu=vfp -O3 -pipe -fstack-protector-strong '
+                             '-fno-plt -march=armv6 -mfloat-abi=hard -mfpu=vfp '
+                             '-O3 -pipe -fstack-protector-strong -fno-plt '
+                             '-march=armv6 -mfloat-abi=hard -mfpu=vfp -O3 '
+                             '-pipe -fstack-protector-strong -fno-plt -std=c99 '
+                             '-Wextra -Wno-unused-result -Wno-unused-parameter '
+                             '-Wno-missing-field-initializers '
+                             '-Wno-cast-function-type '
+                             '-Werror=implicit-function-declaration -I. '
+                             '-I./Include -D_FORTIFY_SOURCE=2 '
+                             '-D_FORTIFY_SOURCE=2 -fPIC '
+                             '-DPy_BUILD_CORE_BUILTIN',
  'PY_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O3 -Wall '
               '-march=armv6 -mfloat-abi=hard -mfpu=vfp -O3 -pipe '
               '-fstack-protector-strong -fno-plt -march=armv6 -mfloat-abi=hard '
@@ -633,10 +649,13 @@ build_time_vars = {'ABIFLAGS': 'm',
                    '-Werror=implicit-function-declaration -I. -I./Include '
                    '-D_FORTIFY_SOURCE=2 -D_FORTIFY_SOURCE=2 -fPIC '
                    '-DPy_BUILD_CORE',
+ 'PY_CORE_LDFLAGS': '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now '
+                    '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now',
  'PY_CPPFLAGS': '-I. -I./Include -D_FORTIFY_SOURCE=2 -D_FORTIFY_SOURCE=2',
  'PY_FORMAT_SIZE_T': '"z"',
  'PY_LDFLAGS': '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now '
                '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now',
+ 'PY_LDFLAGS_NODIST': '',
  'PY_SSL_DEFAULT_CIPHERS': 1,
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
  'PY_STDMODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv '
@@ -658,7 +677,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'READELF': 'readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/build/python/src/Python-3.7.1',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/build/python/src/Python-3.7.2',
  'SCRIPTDIR': '/usr/lib',
  'SETPGRP_HAVE_ARG': 0,
  'SGI_ABI': '@SGI_ABI@',
@@ -700,9 +719,9 @@ build_time_vars = {'ABIFLAGS': 'm',
  'TCLTK_LIBS': '',
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/build/python/src/Python-3.7.1 ./python',
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/build/python/src/Python-3.7.2 ./python',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/build/python/src/Python-3.7.1 ./python '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/build/python/src/Python-3.7.2 ./python '
                './Tools/scripts/run_tests.py',
  'TESTTIMEOUT': 1200,
  'TIMEMODULE_LIB': 0,
@@ -723,8 +742,8 @@ build_time_vars = {'ABIFLAGS': 'm',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/build/python/src/Python-3.7.1',
- 'abs_srcdir': '/build/python/src/Python-3.7.1',
+ 'abs_builddir': '/build/python/src/Python-3.7.2',
+ 'abs_srcdir': '/build/python/src/Python-3.7.2',
  'datarootdir': '/usr/share',
  'exec_prefix': '/usr',
  'prefix': '/usr',
